symbol_component_map

Function symbol_component_map 

pub fn symbol_component_map(graph: &RealityGraph) -> HashMap<String, String>
Map every symbol id to its component id via the component CONTAINS edges (shared by the flow graph compiler and flow projections).