pub fn symbol_component_map(graph: &RealityGraph) -> HashMap<String, String>Expand description
Map every symbol id to its component id via the component CONTAINS edges (shared by the flow graph compiler and flow projections).
pub fn symbol_component_map(graph: &RealityGraph) -> HashMap<String, String>Map every symbol id to its component id via the component CONTAINS edges (shared by the flow graph compiler and flow projections).